Case History

## Jammu Wing

## Case Details

Case Type : HCP
Filing Number: 17594/2015Filing Date: 29-10-2015
Registration Number: 27/2015 Registration Date: 29-10-2015
CNR Number: JKHC02-009178-2015

## Case Status

First Hearing Date : 22nd April 2016
Decision Date: 22nd April 2016
Case Status : CASE DISPOSED
Nature of Disposal: --
Coram : 1153HON'BLE MR. JUSTICE RAMALINGAM SUDHAKAR Bench : Single Bench Judicial : HABEUS CORPUS PETITION (HCP)Short Order : GENERAL Not Before Me :

## Petitioner and Advocate

1) HAKAM SHAH
Advocate- Advocate- A H KAZMI

## Respondent and Advocate

1) STATE TH.HOME DEPTT.AND ORS.

## Subordinate Court Information

Court Number and Name: ---
Case Number and Year: 0
Case Decision Date : : --state:
District:

## IA Details

IA Number | Party | Date of Filing | Next Date | IA Status
--- | --- | --- | --- | ---
IA/1/2015 (1/2015 ) Classification : | HAKAM SHAH STATE TH.HOME DEPTT.AND ORS. | 29-10-2015 | 22-04-2016 | Disposed

## History of Case Hearing

Cause List Type | Judge | Business On Date | Hearing Date | Purpose of hearing
--- | --- | --- | --- | ---
| HON'BLE MR. JUSTICE RAMALINGAM SUDHAKAR | 22-04-2016 |  | Disposed
| HON'BLE MR. JUSTICE RAMALINGAM SUDHAKAR |  | 22-04-2016 | FOR ADMISSION After Notice

## Orders

Order Number | Order on | Judge | Order Date | Order Details

## Category Details

Category | SB HABEAS CORPUS PETITION ( 107 )

## Document Details

Sr. No. | Document No. | Date of Receiving | Filed by | Name of Advocate | Document Filed
--- | --- | --- | --- | --- | ---
1 | 1 | -- | HAKAM SHAH |  | STATUS REPORT